import { R as RemoteUploaderService } from './el-result-CWzWUtHb.js';
import { i as isSafeInteger, a as ContentScriptToBackgroundEvent, b as init_1, f as firstValueFrom, M as MessagePortSubject, c as MAGIC, d as CommonEvent } from './message-CUt9VVap.js';
import { g as getSessionStorage, r as recordStop, w as waitForClientConnect } from './fetch-CBLapmcO.js';
import { b as browser } from './browser-polyfill-DYFaknZ4.js';
import { r as removeTabAvailable, s as setTabAvailable } from './tabs-B_vdYFvW.js';
import { s as setupWebExtensionServer } from './server-DQMjajEz.js';
import './index-Bpyz8kX9.js';
import { b as bridge } from './content-script-BXhZ-Y5h.js';
import './interval-B4vbeOS6.js';
import './switchMap-bmwRNpaI.js';
import './chunk-E2HJRHOS-PVuezkBU.js';
import './chunk-QIZ4XBKF-CktOa0Sh.js';

async function setupIntermediary(bridge) {
    if (!window.parent || window.parent === window) {
        return;
    }
    const { sendMessage } = bridge;
    const tab = await browser.tabs.getCurrent();
    const browserTabId = tab?.id;
    if (!isSafeInteger(browserTabId)) {
        throw new Error();
    }
    const tabId = String(browserTabId);
    const { frameId } = await sendMessage(ContentScriptToBackgroundEvent.GetFrameId, null, 'background');
    const createId = init_1({
        fingerprint: String(frameId)
    });
    const session = getSessionStorage();
    const { onClientConnect, ctx } = setupWebExtensionServer(tabId, {
        session,
        async startRecord (args) {
            const { windowId } = tab;
            if (!windowId) {
                return;
            }
            return await sendMessage(CommonEvent.StartRecord, {
                ...args,
                tabId: browserTabId,
                windowId
            });
        }
    });
    const { recorderState$, container } = ctx;
    RemoteUploaderService.register(container, bridge);
    const isRootFrame = window.top === window.parent;
    if (isRootFrame && recorderState$.getValue().snapshotTabId === String(tabId)) {
        recordStop(recorderState$, false);
    }
    firstValueFrom(waitForClientConnect()).then((event)=>{
        const port = event.ports[0];
        const message$ = new MessagePortSubject(port, String(tab.id));
        onClientConnect(createId(), message$);
        if (isRootFrame) {
            window.onbeforeunload = ()=>{
                removeTabAvailable(browserTabId, String(frameId));
                if (recorderState$.getValue().snapshotTabId === String(tabId)) {
                    recordStop(recorderState$, false);
                }
            };
            return setTabAvailable(browserTabId, String(frameId));
        }
        return undefined;
    });
    window.parent.postMessage(MAGIC, '*');
}

setupIntermediary(bridge);
